@@ -24,10 +24,16 @@
 #define FR_APPLICATION_H
 
 #include <gtk/gtk.h>
+#include <adwaita.h>
 
-G_DECLARE_FINAL_TYPE (FrApplication, fr_application, FR, APPLICATION, GtkApplication)
+G_DECLARE_FINAL_TYPE (FrApplication, fr_application, FR, APPLICATION, AdwApplication)
 
 GtkApplication * fr_application_new           (void);
+
+/**
+ * fr_application_get_settings:
+ * Returns: (transfer none)
+ */
 GSettings *      fr_application_get_settings  (FrApplication *app,
 		     	     	     	       const char    *schema);
 
