@@ -172,8 +172,7 @@ fr_archive_set_property (GObject      *object,
 		fr_archive_set_mime_type (self, g_value_get_string (value));
 		break;
 	case PROP_PASSWORD:
-		g_free (self->password);
-		self->password = g_strdup (g_value_get_string (value));
+		fr_archive_set_password (self, g_value_get_string (value));
 		break;
 	case PROP_ENCRYPT_HEADER:
 		self->encrypt_header = g_value_get_boolean (value);
@@ -530,6 +529,17 @@ fr_archive_get_mime_type (FrArchive  *self)
 }
 
 
+void
+fr_archive_set_password (FrArchive  *self,
+			 const char *new_password)
+{
+	if (self->password == new_password)
+		return;
+	g_free (self->password);
+	self->password = g_strdup (new_password);
+}
+
+
 const char *
 fr_archive_get_packages (FrArchive  *self,
 			 const char *mime_type)
@@ -735,6 +745,7 @@ open_archive_buffer_ready_cb (GObject      *source_object,
 			FR_ERROR_UNSUPPORTED_FORMAT,
 			_("Archive type not supported."));
 		open_data_complete_with_error (open_data, error);
+		return;
 	}
 
 	archive = NULL;
