@@ -24,7 +24,7 @@
 #include <string.h>
 #include <time.h>
 #include <glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -95,7 +95,7 @@ static char **
 split_line_lha (char *line)
 {
 	char       **fields;
-	int          n_fields = 7;
+	int          n_fields = 8;
 	const char  *scan, *field_end;
 	int          i;
 
@@ -104,58 +104,48 @@ split_line_lha (char *line)
 
 	i = 0;
 
-	if (strncmp (line, "[MS-DOS]", 8) == 0) {
-		fields[i++] = g_strdup ("");
-		fields[i++] = g_strdup ("");
-		line += strlen ("[MS-DOS]");
-	}
-	else if (strncmp (line, "[generic]", 9) == 0) {
-		fields[i++] = g_strdup ("");
-		fields[i++] = g_strdup ("");
-		line += strlen ("[generic]");
-	}
-	else if (strncmp (line, "[unknown]", 9) == 0) {
-		fields[i++] = g_strdup ("");
-		fields[i++] = g_strdup ("");
-		line += strlen ("[unknown]");
+	/* First column either contains Unix permissions or OS type, depending
+	 * on what generated the archive. The OS type is enclosed in [brackets]
+	 * and may include a space. */
+	scan = _g_str_eat_spaces (line);
+	if (scan[0] == '[') {
+		field_end = strchr (scan, ']');
+		if (field_end != NULL) {
+			++field_end;
+		}
+	} else {
+		field_end = NULL;
 	}
 
-	scan = _g_str_eat_spaces (line);
-	for (; i < n_fields; i++) {
+	if (field_end == NULL) {
 		field_end = strchr (scan, ' ');
-		if (field_end != NULL) {
-			fields[i] = g_strndup (scan, field_end - scan);
-			scan = _g_str_eat_spaces (field_end);
+		if (field_end == NULL) {
+			field_end = scan + strlen(scan);
 		}
 	}
 
-	return fields;
-}
+	fields[i++] = g_strndup (scan, field_end - scan);
+	scan = field_end;
 
-
-static const char *
-get_last_field_lha (char *line)
-{
-	int         i;
-	const char *field;
-	int         n = 7;
-
-	if (strncmp (line, "[MS-DOS]", 8) == 0)
-		n--;
-
-	if (strncmp (line, "[generic]", 9) == 0)
-		n--;
-
-	if (strncmp (line, "[unknown]", 9) == 0)
-		n--;
-
-	field = _g_str_eat_spaces (line);
-	for (i = 0; i < n; i++) {
-		field = strchr (field, ' ');
-		field = _g_str_eat_spaces (field);
+	/* Second column contains Unix UID/GID, but if the archive was not
+	 * made on a Unix system it will be empty. Insert a dummy value so
+	 * we get a consistent result. */
+	if (g_str_has_prefix (scan, "           ")) {
+		fields[i++] = g_strdup("");
 	}
 
-	return field;
+	scan = _g_str_eat_spaces (scan);
+	for (; i < n_fields; i++) {
+		field_end = strchr (scan, ' ');
+		if (field_end == NULL) {
+			field_end = scan + strlen(scan);
+		}
+
+		fields[i] = g_strndup (scan, field_end - scan);
+		scan = _g_str_eat_spaces (field_end);
+	}
+
+	return fields;
 }
 
 
@@ -163,25 +153,24 @@ static void
 process_line (char     *line,
 	      gpointer  data)
 {
-	FileData    *fdata;
+	FrFileData *fdata;
 	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 
 	g_return_if_fail (line != NULL);
 
-	fdata = file_data_new ();
+	fdata = fr_file_data_new ();
 
 	fields = split_line_lha (line);
 	fdata->size = g_ascii_strtoull (fields[2], NULL, 10);
 	fdata->modified = mktime_from_string (fields[4],
 					      fields[5],
 					      fields[6]);
-	g_strfreev (fields);
 
 	/* Full path */
 
-	name_field = get_last_field_lha (line);
+	name_field = fields[7];
 
 	if (name_field && *name_field == '/') {
 		fdata->full_path = g_strdup (name_field);
@@ -191,6 +180,8 @@ process_line (char     *line,
 		fdata->original_path = fdata->full_path + 1;
 	}
 
+	g_strfreev (fields);
+
 	fdata->link = NULL;
 
 	fdata->dir = line[0] == 'd';
@@ -202,7 +193,7 @@ process_line (char     *line,
 	fdata->path = _g_path_remove_level (fdata->full_path);
 
 	if (*fdata->name == 0)
-		file_data_free (fdata);
+		fr_file_data_free (fdata);
 	else
 		fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 }
@@ -311,12 +302,12 @@ fr_command_lha_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_lha_get_capabilities (FrArchive  *archive,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES;
 	if (_g_program_is_available ("lha", check_command))
@@ -330,7 +321,7 @@ static const char *
 fr_command_lha_get_packages (FrArchive  *archive,
 			     const char *mime_type)
 {
-	return PACKAGES ("lha");
+	return FR_PACKAGES ("lha");
 }
 
 
