@@ -28,7 +28,7 @@
 #include <time.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -127,7 +127,7 @@ static void
 process_line (char     *line,
 	      gpointer  data)
 {
-	FileData    *fdata;
+	FrFileData *fdata;
 	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	int          date_idx;
@@ -140,7 +140,7 @@ process_line (char     *line,
 	if (date_idx < 0)
 		return;
 
-	fdata = file_data_new ();
+	fdata = fr_file_data_new ();
 
 	field_size = _g_line_get_prev_field (line, date_idx, 1);
 	fdata->size = g_ascii_strtoull (field_size, NULL, 10);
@@ -188,7 +188,7 @@ process_line (char     *line,
 	fdata->path = _g_path_remove_level (fdata->full_path);
 
 	if (*fdata->name == 0)
-		file_data_free (fdata);
+		fr_file_data_free (fdata);
 	else
 		fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 }
@@ -208,6 +208,9 @@ add_compress_arg (FrCommand *comm)
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip-compressed-tar"))
 		fr_process_add_arg (comm->process, "--use-compress-program=bzip2");
 
+	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip3-compressed-tar"))
+		fr_process_add_arg (comm->process, "--use-compress-program=bzip3");
+
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-tarz")) {
 		if (_g_program_is_in_path ("gzip"))
 			fr_process_add_arg (comm->process, "-z");
@@ -588,6 +591,27 @@ fr_command_tar_recompress (FrCommand *comm)
 
 		new_name = g_strconcat (c_tar->uncomp_filename, ".bz2", NULL);
 	}
+	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip3-compressed-tar")) {
+		fr_process_begin_command (comm->process, "bzip3");
+		fr_process_set_begin_func (comm->process, begin_func__recompress, comm);
+		//switch (archive->compression) {
+		//case FR_COMPRESSION_VERY_FAST:
+		//	fr_process_add_arg (comm->process, "-1"); break;
+		//case FR_COMPRESSION_FAST:
+		//	fr_process_add_arg (comm->process, "-3"); break;
+		//case FR_COMPRESSION_NORMAL:
+		//	fr_process_add_arg (comm->process, "-6"); break;
+		//case FR_COMPRESSION_MAXIMUM:
+		//	fr_process_add_arg (comm->process, "-9"); break;
+		//}
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-e");
+		fr_process_add_arg (comm->process, "--");
+		fr_process_add_arg (comm->process, c_tar->uncomp_filename);
+		fr_process_end_command (comm->process);
+
+		new_name = g_strconcat (c_tar->uncomp_filename, ".bz3", NULL);
+	}
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-tarz")) {
 		fr_process_begin_command (comm->process, "compress");
 		fr_process_set_begin_func (comm->process, begin_func__recompress, comm);
@@ -861,6 +885,17 @@ get_uncompressed_name (FrCommandTar *c_tar,
 		else if (_g_filename_has_extension (e_filename, ".tar.bz2"))
 			new_name[l - 4] = 0;
 	}
+	else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip3-compressed-tar")) {
+		/* X.tbz3    -->  X.tar
+		 * X.tar.bz3 -->  X.tar */
+		if (_g_filename_has_extension (e_filename, ".tbz3")) {
+			new_name[l - 3] = 'a';
+			new_name[l - 2] = 'r';
+			new_name[l - 1] = 0;
+		}
+		else if (_g_filename_has_extension (e_filename, ".tar.bz3"))
+			new_name[l - 4] = 0;
+	}
 	else if (_g_mime_type_matches (archive->mime_type, "application/x-tarz")) {
 		/* X.taz   -->  X.tar
 		 * X.tar.Z -->  X.tar */
@@ -962,7 +997,7 @@ get_temp_name (FrCommandTar *c_tar,
 	char *temp_name = NULL;
 
 	template = g_strconcat (dirname, "/.fr-XXXXXX", NULL);
-	result = mkdtemp (template);
+	result = g_mkdtemp (template);
 	temp_name = g_build_filename (result, _g_path_get_basename (filepath), NULL);
 	g_free (template);
 
@@ -1036,6 +1071,16 @@ fr_command_tar_uncompress (FrCommand *comm)
 			fr_process_add_arg (comm->process, tmp_name);
 			fr_process_end_command (comm->process);
 		}
+		else if (_g_mime_type_matches (archive->mime_type, "application/x-bzip3-compressed-tar")) {
+			fr_process_begin_command (comm->process, "bzip3");
+			fr_process_set_working_dir (comm->process, tmp_dir);
+			fr_process_set_begin_func (comm->process, begin_func__uncompress, comm);
+			fr_process_add_arg (comm->process, "-f");
+			fr_process_add_arg (comm->process, "-d");
+			fr_process_add_arg (comm->process, "--");
+			fr_process_add_arg (comm->process, tmp_name);
+			fr_process_end_command (comm->process);
+		}
 		else if (_g_mime_type_matches (archive->mime_type, "application/x-tarz")) {
 			if (_g_program_is_in_path ("gzip")) {
 				fr_process_begin_command (comm->process, "gzip");
@@ -1161,6 +1206,7 @@ fr_command_tar_handle_error (FrCommand   *comm,
 const char *tar_mime_types[] = { "application/x-compressed-tar",
 				 "application/x-brotli-compressed-tar",
 				 "application/x-bzip-compressed-tar",
+				 "application/x-bzip3-compressed-tar",
 				 "application/x-tar",
 				 "application/x-7z-compressed-tar",
 				 "application/x-lrzip-compressed-tar",
@@ -1182,12 +1228,12 @@ fr_command_tar_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_tar_get_capabilities (FrArchive  *archive,
 			         const char *mime_type,
 				 gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES;
 
@@ -1210,6 +1256,10 @@ fr_command_tar_get_capabilities (FrArchive  *archive,
 		if (_g_program_is_available ("bzip2", check_command))
 			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
 	}
+	else if (_g_mime_type_matches (mime_type, "application/x-bzip3-compressed-tar")) {
+		if (_g_program_is_available ("bzip3", check_command))
+			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
+	}
 	else if (_g_mime_type_matches (mime_type, "application/x-tarz")) {
 		if (_g_program_is_available ("compress", check_command) && _g_program_is_available ("uncompress", check_command))
 			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
@@ -1241,10 +1291,9 @@ fr_command_tar_get_capabilities (FrArchive  *archive,
 			capabilities |= FR_ARCHIVE_CAN_READ_WRITE;
 	}
 	else if (_g_mime_type_matches (mime_type, "application/x-7z-compressed-tar")) {
-		char *try_command[3] = { "7za", "7zr", "7z" };
-		int   i;
+		char *try_command[5] = { "7zzs", "7zz", "7za", "7zr", "7z" };
 
-		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
+		for (size_t i = 0; i < G_N_ELEMENTS (try_command); i++) {
 			if (_g_program_is_available (try_command[i], check_command)) {
 				capabilities |= FR_ARCHIVE_CAN_WRITE;
 				break;
@@ -1273,10 +1322,9 @@ fr_command_tar_set_mime_type (FrArchive  *archive,
 	FR_ARCHIVE_CLASS (fr_command_tar_parent_class)->set_mime_type (archive, mime_type);
 
 	if (_g_mime_type_matches (mime_type, "application/x-7z-compressed-tar")) {
-		char *try_command[3] = { "7za", "7zr", "7z" };
-		int   i;
+		char *try_command[5] = { "7zzs", "7zz", "7za", "7zr", "7z" };
 
-		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
+		for (size_t i = 0; i < G_N_ELEMENTS (try_command); i++) {
 			if (_g_program_is_in_path (try_command[i])) {
 				comm_tar->compress_command = g_strdup (try_command[i]);
 				break;
@@ -1291,33 +1339,35 @@ fr_command_tar_get_packages (FrArchive  *archive,
 			     const char *mime_type)
 {
 	if (_g_mime_type_matches (mime_type, "application/x-tar"))
-		return PACKAGES ("tar");
+		return FR_PACKAGES ("tar");
 	else if (_g_mime_type_matches (mime_type, "application/x-compressed-tar"))
-		return PACKAGES ("tar,gzip");
+		return FR_PACKAGES ("tar,gzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-brotli-compressed-tar"))
-		return PACKAGES ("tar,brotli");
+		return FR_PACKAGES ("tar,brotli");
 	else if (_g_mime_type_matches (mime_type, "application/x-bzip-compressed-tar"))
-		return PACKAGES ("tar,bzip2");
+		return FR_PACKAGES ("tar,bzip2");
+	else if (_g_mime_type_matches (mime_type, "application/x-bzip3-compressed-tar"))
+		return FR_PACKAGES ("tar,bzip3");
 	else if (_g_mime_type_matches (mime_type, "application/x-tarz"))
-		return PACKAGES ("tar,gzip,ncompress");
+		return FR_PACKAGES ("tar,gzip,ncompress");
 	else if (_g_mime_type_matches (mime_type, "application/x-lrzip-compressed-tar"))
-		return PACKAGES ("tar,lrzip");
+		return FR_PACKAGES ("tar,lrzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-lz4-compressed-tar"))
-		return PACKAGES ("tar,lz4");
+		return FR_PACKAGES ("tar,lz4");
 	else if (_g_mime_type_matches (mime_type, "application/x-lzip-compressed-tar"))
-		return PACKAGES ("tar,lzip");
+		return FR_PACKAGES ("tar,lzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-lzma-compressed-tar"))
-		return PACKAGES ("tar,lzma");
+		return FR_PACKAGES ("tar,lzma");
 	else if (_g_mime_type_matches (mime_type, "application/x-xz-compressed-tar"))
-		return PACKAGES ("tar,xz");
+		return FR_PACKAGES ("tar,xz");
 	else if (_g_mime_type_matches (mime_type, "application/x-tzo"))
-		return PACKAGES ("tar,lzop");
+		return FR_PACKAGES ("tar,lzop");
 	else if (_g_mime_type_matches (mime_type, "application/x-7z-compressed-tar"))
-		return PACKAGES ("tar,p7zip");
+		return FR_PACKAGES ("tar,7zip");
 	else if (_g_mime_type_matches (mime_type, "application/x-rzip-compressed-tar"))
-		return PACKAGES ("tar,rzip");
+		return FR_PACKAGES ("tar,rzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-zstd-compressed-tar"))
-		return PACKAGES ("tar,zstd");
+		return FR_PACKAGES ("tar,zstd");
 
 	return NULL;
 }
