@@ -71,6 +71,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-arj",                     ".arj",      0 },
 	{ "application/x-brotli",                  ".br",       0 },
 	{ "application/x-brotli-compressed-tar",   ".tar.br",   0 },
+	{ "application/x-bzip3",                   ".bz3",      0 },
+	{ "application/x-bzip3-compressed-tar",    ".tar.bz3",  0 },
 	{ "application/x-bzip",                    ".bz2",      0 },
 	{ "application/x-bzip-compressed-tar",     ".tar.bz2",  0 },
 	{ "application/x-bzip1",                   ".bz",       0 },
@@ -135,6 +137,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".br", "application/x-brotli" },
 	{ ".bz", "application/x-bzip" },
 	{ ".bz2", "application/x-bzip" },
+	{ ".bz3", "application/x-bzip3" },
 	{ ".cab", "application/vnd.ms-cab-compressed" },
 	{ ".cbr", "application/x-cbr" },
 	{ ".cbz", "application/x-cbz" },
@@ -167,6 +170,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.br", "application/x-brotli-compressed-tar" },
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
+	{ ".tar.bz3", "application/x-bzip3-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
 	{ ".tar.lrz", "application/x-lrzip-compressed-tar" },
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
@@ -181,6 +185,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".taz", "application/x-tarz" },
 	{ ".tbz", "application/x-bzip-compressed-tar" },
 	{ ".tbz2", "application/x-bzip-compressed-tar" },
+	{ ".tbz3", "application/x-bzip3-compressed-tar" },
 	{ ".tgz", "application/x-compressed-tar" },
 	{ ".txz", "application/x-xz-compressed-tar" },
 	{ ".tlz", "application/x-lzip-compressed-tar" },
