@@ -420,14 +420,6 @@ void            fr_window_set_notify                   (FrWindow      *window,
 
 /**/
 
-/**
- * fr_window_file_list_drag_data_get:
- * @path_list: (element-type GtkTreeRowReference)
- */
-gboolean        fr_window_file_list_drag_data_get      (FrWindow         *window,
-						        GdkDragContext   *context,
-						        GtkSelectionData *selection_data,
-						        GList            *path_list);
 void            fr_window_update_dialog_closed         (FrWindow         *window);
 void		fr_window_dnd_extraction_finished      (FrWindow	 *window,
 							gboolean	  error);
@@ -444,4 +436,6 @@ void            fr_window_extract_archive_and_continue (FrWindow   *window,
 							FrOverwrite overwrite,
 							gboolean    junk_paths);
 
+void            fr_window_focus_location               (FrWindow   *window);
+
 #endif /* FR_WINDOW_H */
