@@ -110,8 +110,12 @@ void          _gtk_box_pack_end              (GtkBox     *box,
 void          _gtk_widget_set_margin         (GtkWidget  *widget,
 					      int         margin);
 void          _gtk_show_folder               (GtkWindow  *parent_window,
-					      GFile      *folder);
+					      GFile      *folder,
+					      GFunc       callback,
+					      gpointer    user_data);
 void          _gtk_show_file_in_container    (GtkWindow  *window,
-					      GFile      *file);
+					      GFile      *file,
+					      GFunc       callback,
+					      gpointer    user_data);
 
 #endif
